const char *usage_msg[] = {
	"  -a: append to ALF file.",
	"  -A: convert EOLs and tabs in all input files.",
	"  -h: show this help message.",
	"  -o: overwrite ALF file if it exists (don't create file~ backup).",
	"  -q: quiet.",
	"  -td: use default LZ.COM timestamps.",
	"  -tu: use UTC timestamps.",
	"  -tz: use zero timestamps.",
	"  -v: verbose (-vv: debug).",
	"  -V: show version number.",
	"  --: end of options (next arg is alf-file).",
	(const char*)0
};
